@@ -44,6 +44,7 @@ def parse_ts(filename):
 
 
 
+parse_ts("hydrogen.cs.ts")
 parse_ts("hydrogen.de.ts")
 parse_ts("hydrogen.ca.ts")
 parse_ts("hydrogen.fr.ts")
@@ -57,3 +58,6 @@ parse_ts("hydrogen.ja.ts")
 parse_ts("hydrogen.pl.ts")
 parse_ts("hydrogen.ru.ts")
 parse_ts("hydrogen.hr.ts")
+parse_ts("hydrogen.el.ts")
+parse_ts("hydrogen.gl.ts")
+parse_ts("hydrogen.sr.ts")
